@@ -4,7 +4,7 @@ use Novel::Robot::Browser;
 use URI;
 use Encode;
 
-our $VERSION    = 0.21;
+our $VERSION    = 0.22;
 
 our %NULL_INDEX = (
     url          => '',
@@ -64,6 +64,9 @@ sub detect_site {
       : ( $url =~ m#^\Qhttp://www.23us.com/# )    ? 'dingdian'
       : ( $url =~ m#^\Qhttp://read.qidian.com/# ) ? 'qidian'
       : ( $url =~ m#^\Qhttp://www.snwx.com/# )    ? 'snwx'
+      : ( $url =~ m#^\Qhttp://www.hkslg.com/# )    ? 'hkslg'
+      : ( $url =~ m#^\Qhttp://www.tadu.com/# )    ? 'tadu'
+      : ( $url =~ m#^\Qhttp://www.zilang.net/# )    ? 'zilang'
       : ( $url =~ m#^\Qhttp://bbs.jjwxc.net/# )   ? 'hjj'
       : ( $url =~ m#^\Qhttp://tieba.baidu.com/# ) ? 'tieba'
       :                                             'unknown';
@@ -403,6 +406,12 @@ sub format_hashref_string {
     $r;
 }
 
+sub unescape_js {
+    my ($self, $s) = @_;
+    $s =~ s/%u([0-9a-f]{4})/chr(hex($1))/eigs;
+    $s =~ s/%([0-9a-f]{2})/chr(hex($1))/eigs;
+    return $s;
+}
 
 1;
 
